/*******************************************************
**  
** Binding Lua to access Window's registry.
** 
** Mark Stroetzel Glasberg  - Overweb
** 02 Dec, 2003
**
********************************************************/

#include <stdio.h>
#include <windows.h>
#include <winreg.h>
#include "registry.h"

extern "C" 
{
#include <lua.h>
#include <lualib.h>
#include <lauxlib.h>
#include "luacompat.h"
}

// binding to C function that reads the registry
static int c_readregistry(lua_State* L) 
{
  if(!lua_isstring(L, 1) || !lua_isstring(L, 2) || !lua_isstring(L, 3))
  {
    luaCompat_error(L, "readregistry: wrong arguments");
    return 0;
  }

  char *ret = Registry::readregistry(lua_tostring(L, 1), lua_tostring(L, 2), lua_tostring(L, 3));
  if(ret)
    lua_pushstring(L, ret);
  else
    lua_pushnil(L);

  return 1;
}

// binding to C function that changes the registry
static int c_changeregistry(lua_State* L) 
{
  if(!lua_isstring(L, 1) || !lua_isstring(L, 2) || !lua_isstring(L, 3) || !lua_isstring(L, 4))
  {
    luaCompat_error(L, "changeregistry: wrong arguments");
    return 0;
  }

  int ret = Registry::changeregistry(lua_tostring(L, 1), lua_tostring(L, 2), lua_tostring(L, 3), lua_tostring(L, 4));
  lua_pushnumber(L, ret);

  return 1;
}

// binding to C function that deletes the registry
static int c_deleteregistry(lua_State* L) 
{
  if(!lua_isstring(L, 1) || !lua_isstring(L, 2) || !lua_isstring(L, 3))
  {
    luaCompat_error(L, "deleteregistry: wrong arguments");
    return 0;
  }

  int ret = Registry::deleteregistry(lua_tostring(L, 1), lua_tostring(L, 2), lua_tostring(L, 3));
  lua_pushnumber(L, ret);

  return 1;
}

// Registers Lua functions that change registry information
void RegistryLua(lua_State *L)
{
  lua_register(L, "readregistry",   c_readregistry);
  lua_register(L, "changeregistry", c_changeregistry);
  lua_register(L, "deleteregistry", c_deleteregistry);
}  
